Module collector

Module collector 

This module contains the functionality for generating reports.

Structs

RepositoryCollector
A unit struct that provides Self::run(), which is used to generated RepositoryCollection.

Enums

CollectorError

Type Aliases

CollectorResult
The result type used when multiple kinds of errors can be encountered during collection.
RepositoryCollection
This type represents a BTreeMap using an optional String for keys, which represents the parent directory for a group of reports (Vec<RepositoryView>). The values corresponding to those keys are the actual groups of reports.