This module contains the functionality for generating reports.
Structs
- Repository
Collector - A unit struct that provides
Self::run(), which is used to generatedRepositoryCollection.
Enums
Type Aliases
- Collector
Result - The result type used when multiple kinds of errors can be encountered during collection.
- Repository
Collection - This type represents a
BTreeMapusing an optionalStringfor keys, which represents the parent directory for a group of reports (Vec<RepositoryView>). The values corresponding to those keys are the actual groups of reports.